Improve this Doc View Source
Deprecated:

In an effort to keep synchronized with router changes in Angular 2, this implementation of the Component Router (ngComponentRouter module) has been deprecated and will not receive further updates. We are investigating backporting the Angular 2 Router to Angular 1, but alternatively, use the `ngRoute` module or community developed projects (e.g. ui-router).

Each item in the RouteConfig for a Routing Component is an instance of this type. It can have the following properties:

- `path` or (`regex` and `serializer`) - defines how to recognize and generate this route
- `component`, `loader`, `redirectTo` (requires exactly one of these)
- `name` - the name used to identify the Route Definition when generating links
- `data` (optional)